=======
Credits
=======

Development Lead
----------------

* Christian Kragh Jespersen <ckragh@princeton.edu>, astrockragh

Contributors
------------

Adapted from IDL code written by Benjamin Moster
